{
    "$graph": [
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "expression": " ${ inputs.main_file.secondaryFiles = Array.isArray(inputs.secondary_files) ? inputs.secondary_files : [inputs.secondary_files];\nreturn { \"file_with_secondary_files\": inputs.main_file } } ",
            "doc": "Step to put secondary input files in the same folder as a main file",
            "inputs": [
                {
                    "type": "File",
                    "id": "#combine_files.cwl/main_file"
                },
                {
                    "type": [
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "id": "#combine_files.cwl/secondary_files"
                }
            ],
            "id": "#combine_files.cwl",
            "outputs": [
                {
                    "type": "File",
                    "id": "#combine_files.cwl/file_with_secondary_files"
                }
            ]
        },
        {
            "id": "#GenomicsDBImport.cwl",
            "baseCommand": [
                "python3",
                "/gatk-tmpdir-output-wrapper.py",
                "[\"--genomicsdb-workspace-path\"]",
                "[\"-Xmx4g\",\"-Xms4g\"]",
                "GenomicsDBImport"
            ],
            "class": "CommandLineTool",
            "doc": "Import single-sample GVCFs into GenomicsDB before joint genotyping.\n\n <p>The GATK4 Best Practice Workflow for SNP and Indel calling uses GenomicsDBImport to merge GVCFs from multiple samples.\n GenomicsDBImport offers the same functionality as CombineGVCFs and comes from the <i>Intel-Broad Center for Genomics</i>.\n The datastore transposes sample-centric variant information across genomic loci to make data more accessible to tools.\n </p>\n\n <p>To query the contents of the GenomicsDB datastore, use\n <a href='https://software.broadinstitute.org/gatk/documentation/tooldocs/current/org_broadinstitute_gatk_tools_walkers_variantutils_SelectVariants.php'>SelectVariants</a>.\n See <a href='https://software.broadinstitute.org/gatk/documentation/article?id=10061'>Tutorial#10061</a> to get started. </p>\n\n <p>Details on GenomicsDB are at\n <a href='https://github.com/Intel-HLS/GenomicsDB/wiki'>https://github.com/Intel-HLS/GenomicsDB/wiki</a>.\n In brief, GenomicsDB is a utility built on top of TileDB. TileDB is a format for efficiently representing sparse data.\n Genomics data is typically sparse in that each sample has few variants with respect to the entire reference genome.\n GenomicsDB contains code to specialize TileDB for genomics applications, such as VCF parsing and INFO field annotation\n calculation.\n </p>\n\n <h3>Input</h3>\n <p>\n One or more GVCFs produced by in HaplotypeCaller with the `-ERC GVCF` or `-ERC BP_RESOLUTION` settings, containing\n the samples to joint-genotype.\n </p>\n\n <h3>Output</h3>\n <p>\n A GenomicsDB workspace\n </p>\n\n  <h3>Usage examples</h3>\n\n  Provide each sample GVCF separately.\n  <pre>\n    gatk --java-options \"-Xmx4g -Xms4g\" GenomicsDBImport \\\n      -V data/gvcfs/mother.g.vcf.gz \\\n      -V data/gvcfs/father.g.vcf.gz \\\n      -V data/gvcfs/son.g.vcf.gz \\\n      --genomicsdb-workspace-path my_database \\\n      -L 20\n  </pre>\n\n  Provide sample GVCFs in a map file.\n\n  <pre>\n    gatk --java-options \"-Xmx4g -Xms4g\" \\\n       GenomicsDBImport \\\n       --genomicsdb-workspace-path my_database \\\n       --batch-size 50 \\\n       -L chr1:1000-10000 \\\n       --sample-name-map cohort.sample_map \\\n       --reader-threads 5\n  </pre>\n\n  The sample map is a tab-delimited text file with sample_name--tab--path_to_sample_vcf per line. Using a sample map\n  saves the tool from having to download the GVCF headers in order to determine the sample names.\n\n  <pre>\n  sample1      sample1.vcf.gz\n  sample2      sample2.vcf.gz\n  sample3      sample3.vcf.gz\n  </pre>\n\n <h3>Caveats</h3>\n <ul>\n     <li>IMPORTANT: The -Xmx value the tool is run with should be less than the total amount of physical memory available by at least a few GB, as the native TileDB library requires additional memory on top of the Java memory. Failure to leave enough memory for the native code can result in confusing error messages!</li>\n     <li>A single interval must be provided. This means each import is limited to a maximum of one contig</li>\n     <li>Currently, only supports diploid data</li>\n     <li>Input GVCFs cannot contain multiple entries for a single genomic position</li>\n     <li>The --genomicsdb-workspace-path must point to a non-existent or empty directory.</li>\n </ul>\n\n <h3>Developer Note</h3>\n To read data from GenomicsDB, use the query interface com.intel.genomicsdb.GenomicsDBFeatureReader",
            "temporaryFailCodes": [
                3
            ],
            "hints": [
                {
                    "outputDirType": "keep_output_dir",
                    "class": "http://arvados.org/cwl#RuntimeConstraints"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "/**\n * File of functions to be added to cwl files\n */\n\nfunction generateGATK4BooleanValue(){\n    /**\n     * Boolean types in GATK 4 are expressed on the command line as --<PREFIX> \"true\"/\"false\",\n     * so patch here\n     */\n    if(self === true || self === false){\n        return self.toString()\n    }\n\n    return self;\n}\n\nfunction addTagToArgument(tagObject, argument, prefix){\n    var allTags = Array.isArray(tagObject) ? tagObject.join(\",\") : tagObject;\n    return [prefix + \":\" + allTags, argument];\n}\n\nfunction applyTagsToArgument(prefix, tags){\n    /**\n     * Function to be used in the field valueFrom of File objects to add gatk tags.\n     */\n\n    if(!self){\n        return null;\n    }\n    else if(!tags){\n        return generateArrayCmd(prefix);\n    }\n    else{\n        if(Array.isArray(self)){\n            if(!Array.isArray(tags) || self.length !== tags.length){\n                throw new TypeError(\"Argument '\" + prefix + \"' tag field is invalid\");\n            }\n\n            var value = self.map(function(element, i) {\n                return addTagToArgument(tags[i], element);\n            }).reduce(function(a, b){return a.concat(b)})\n\n            return value;\n        }\n        else{\n            return addTagToArgument(tags, self);\n        }\n    }\n}\n\nfunction generateArrayCmd(prefix){\n    /**\n     * Function to be used in the field valueFrom of array objects, so that arrays are optional\n     * and prefixes are handled properly.\n     *\n     * The issue that this solves is documented here:\n     * https://www.biostars.org/p/258414/#260140\n     */\n    if(!self){\n        return null;\n    }\n\n    if(!Array.isArray(self)){\n        self = [self];\n    }\n\n    var output = [];\n    self.forEach(function(element) {\n        output.push(prefix);\n        output.push(element);\n    })\n\n    return output;\n}"
                    ]
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mercury/gatk-4.0.0.0-tmpdir-output-wrapper:v2"
                }
            ],
            "inputs": [
                {
                    "doc": "Reference sequence",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/reference",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--reference\", inputs['reference_tags']))"
                    },
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ]
                },
                {
                    "doc": "BAM/SAM/CRAM file containing reads",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/input",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--input\", inputs['input_tags']))"
                    },
                    "secondaryFiles": ".crai"
                },
                {
                    "doc": "Threshold number of ambiguous bases. If null, uses threshold fraction; otherwise, overrides threshold fraction.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/ambig-filter-bases",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--ambig-filter-bases"
                    }
                },
                {
                    "doc": "Threshold fraction of ambiguous bases",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/ambig-filter-frac",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--ambig-filter-frac"
                    }
                },
                {
                    "doc": "Maximum length of fragment (insert size)",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/max-fragment-length",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-fragment-length"
                    }
                },
                {
                    "doc": "Name of the library to keep",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/library",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--library\"))"
                    }
                },
                {
                    "doc": "Maximum mapping quality to keep (inclusive)",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/maximum-mapping-quality",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--maximum-mapping-quality"
                    }
                },
                {
                    "doc": "Minimum mapping quality to keep (inclusive)",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/minimum-mapping-quality",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--minimum-mapping-quality"
                    }
                },
                {
                    "doc": "Allow a read to be filtered out based on having only 1 soft-clipped block. By default, both ends must have a soft-clipped block, setting this flag requires only 1 soft-clipped block",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/dont-require-soft-clips-both-ends",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--dont-require-soft-clips-both-ends",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Minimum number of aligned bases",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/filter-too-short",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--filter-too-short"
                    }
                },
                {
                    "doc": "Platform attribute (PL) to match",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/platform-filter-name",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--platform-filter-name\"))"
                    }
                },
                {
                    "doc": "Platform unit (PU) to filter out",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/black-listed-lanes",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--black-listed-lanes\"))"
                    }
                },
                {
                    "doc": "The name of the read group to filter out",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/read-group-black-list",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--read-group-black-list\"))"
                    }
                },
                {
                    "doc": "The name of the read group to keep",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/keep-read-group",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--keep-read-group"
                    }
                },
                {
                    "doc": "Keep only reads with length at most equal to the specified value",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/max-read-length",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-read-length"
                    }
                },
                {
                    "doc": "Keep only reads with length at least equal to the specified value",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/min-read-length",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--min-read-length"
                    }
                },
                {
                    "doc": "Keep only reads with this read name",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/read-name",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--read-name"
                    }
                },
                {
                    "doc": "Keep only reads on the reverse strand",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/keep-reverse-strand-only",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--keep-reverse-strand-only",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "The name of the sample(s) to keep, filtering out all others",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/sample",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--sample\"))"
                    }
                },
                {
                    "doc": "If true, adds a PG tag to created SAM/BAM/CRAM files.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/add-output-sam-program-record",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--add-output-sam-program-record",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, adds a command line header line to created VCF files.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/add-output-vcf-command-line",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--add-output-vcf-command-line",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "read one or more arguments files and add them to the command line",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/arguments_file",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--arguments_file\", inputs['arguments_file_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                {
                                    "type": "array",
                                    "items": "string"
                                }
                            ]
                        }
                    ],
                    "doc": "A argument to set the tags of 'arguments_file'",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/arguments_file_tags"
                },
                {
                    "doc": "Batch size controls the number of samples for which readers are open at once and therefore provides a way to minimize memory consumption. However, it can take longer to complete. Use the consolidate flag if more than a hundred batches were used. This will improve feature read time. batchSize=0 means no batching (i.e. readers for all samples will be opened at once) Defaults to 0",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/batch-size",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--batch-size"
                    }
                },
                {
                    "doc": "Size of the cloud-only prefetch buffer (in MB; 0 to disable). Defaults to cloudPrefetchBuffer if unset.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/cloud-index-prefetch-buffer",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--cloud-index-prefetch-buffer"
                    }
                },
                {
                    "doc": "Size of the cloud-only prefetch buffer (in MB; 0 to disable).",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/cloud-prefetch-buffer",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--cloud-prefetch-buffer"
                    }
                },
                {
                    "doc": "Boolean flag to enable consolidation. If importing data in batches, a new fragment is created for each batch. In case thousands of fragments are created, GenomicsDB feature readers will try to open ~20x as many files. Also, internally GenomicsDB would consume more memory to maintain bookkeeping data from all fragments. Use this flag to merge all fragments into one. Merging can potentially improve read performance, however overall benefit might not be noticeable as the top Java layers have significantly higher overheads. This flag has no effect if only one batch is used. Defaults to false",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/consolidate",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--consolidate",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, create a BAM/CRAM index when writing a coordinate-sorted BAM/CRAM file.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/create-output-bam-index",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--create-output-bam-index",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, create a MD5 digest for any BAM/SAM/CRAM file created",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/create-output-bam-md5",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--create-output-bam-md5",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, create a VCF index when writing a coordinate-sorted VCF file.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/create-output-variant-index",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--create-output-variant-index",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, create a a MD5 digest any VCF file created.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/create-output-variant-md5",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--create-output-variant-md5",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, don't cache bam indexes, this will reduce memory requirements but may harm performance if many intervals are specified.  Caching is automatically disabled if there are no intervals specified.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/disable-bam-index-caching",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--disable-bam-index-caching",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Read filters to be disabled before analysis",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/disable-read-filter",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--disable-read-filter\"))"
                    }
                },
                {
                    "doc": "If specified, do not check the sequence dictionaries from our inputs for compatibility. Use at your own risk!",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/disable-sequence-dictionary-validation",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--disable-sequence-dictionary-validation",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Disable all tool default read filters",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/disable-tool-default-read-filters",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--disable-tool-default-read-filters",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "One or more genomic intervals to exclude from processing",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/exclude-intervals",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--exclude-intervals\"))"
                    }
                },
                {
                    "doc": "A configuration file to use with the GATK.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/gatk-config-file",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--gatk-config-file\", inputs['gatk-config-file_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'gatk-config-file'",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/gatk-config-file_tags"
                },
                {
                    "doc": "If the GCS bucket channel errors out, how many times it will attempt to re-initiate the connection",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/gcs-max-retries",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--gcs-max-retries"
                    }
                },
                {
                    "doc": "Buffer size in bytes allocated for GenomicsDB attributes during import. Should be large enough to hold data from one site.  Defaults to 1048576",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/genomicsdb-segment-size",
                    "type": [
                        "null",
                        "long"
                    ],
                    "inputBinding": {
                        "prefix": "--genomicsdb-segment-size"
                    }
                },
                {
                    "doc": "Buffer size in bytes to store variant contexts. Larger values are better as smaller values cause frequent disk writes. Defaults to 16384 which was empirically determined to work well for many inputs.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/genomicsdb-vcf-buffer-size",
                    "type": [
                        "null",
                        "long"
                    ],
                    "inputBinding": {
                        "prefix": "--genomicsdb-vcf-buffer-size"
                    }
                },
                {
                    "doc": "Workspace for GenomicsDB. Must be a POSIX file system path, but can be a relative path. Must be an empty or non-existent directory.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/genomicsdb-workspace-path",
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--genomicsdb-workspace-path"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                {
                                    "type": "array",
                                    "items": "string"
                                }
                            ]
                        }
                    ],
                    "doc": "A argument to set the tags of 'input'",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/input_tags"
                },
                {
                    "doc": "Amount of padding (in bp) to add to each interval you are excluding.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/interval-exclusion-padding",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--interval-exclusion-padding"
                    }
                },
                {
                    "doc": "Interval merging rule for abutting intervals",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/interval-merging-rule",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#GenomicsDBImport.cwl/GenomicsDBImport/interval-merging-rule/ALL",
                                "#GenomicsDBImport.cwl/GenomicsDBImport/interval-merging-rule/OVERLAPPING_ONLY"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--interval-merging-rule"
                    }
                },
                {
                    "doc": "Amount of padding (in bp) to add to each interval you are including.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/interval-padding",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--interval-padding"
                    }
                },
                {
                    "doc": "Set merging approach to use for combining interval inputs",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/interval-set-rule",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#GenomicsDBImport.cwl/GenomicsDBImport/interval-set-rule/UNION",
                                "#GenomicsDBImport.cwl/GenomicsDBImport/interval-set-rule/INTERSECTION"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--interval-set-rule"
                    }
                },
                {
                    "doc": "One or more genomic intervals over which to operate",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/intervals",
                    "type": [
                        "File",
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--intervals\", inputs['intervals_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'intervals'",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/intervals_tags"
                },
                {
                    "doc": "Lenient processing of VCF files",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/lenient",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--lenient",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Will overwrite given workspace if it exists. Otherwise a new workspace is created. Defaults to false",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/overwrite-existing-genomicsdb-workspace",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--overwrite-existing-genomicsdb-workspace",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Whether to suppress job-summary info on System.err.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/QUIET",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--QUIET",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Read filters to be applied before analysis",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/read-filter",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--read-filter\"))"
                    }
                },
                {
                    "doc": "Indices to use for the read inputs. If specified, an index must be provided for every read input and in the same order as the read inputs. If this argument is not specified, the path to the index for each input will be inferred automatically.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/read-index",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--read-index\"))"
                    }
                },
                {
                    "doc": "Validation stringency for all SAM/BAM/CRAM/SRA files read by this program.  The default stringency value SILENT can improve performance when processing a BAM file in which variable-length data (read, qualities, tags) do not otherwise need to be decoded.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/read-validation-stringency",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#GenomicsDBImport.cwl/GenomicsDBImport/read-validation-stringency/STRICT",
                                "#GenomicsDBImport.cwl/GenomicsDBImport/read-validation-stringency/LENIENT",
                                "#GenomicsDBImport.cwl/GenomicsDBImport/read-validation-stringency/SILENT"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--read-validation-stringency"
                    }
                },
                {
                    "doc": "How many simultaneous threads to use when opening VCFs in batches; higher values may improve performance when network latency is an issue",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/reader-threads",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--reader-threads"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'reference'",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/reference_tags"
                },
                {
                    "doc": "Path to file containing a mapping of sample name to file uri in tab delimited format.  If this is specified then the header from the first sample will be treated as the merged header rather than merging the headers, and the sample names will be taken from this file.  This may be used to rename input samples. This is a performance optimization that relaxes the normal checks for consistent headers.  Using vcfs with incompatible headers may result in silent data corruption.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/sample-name-map",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--sample-name-map\", inputs['sample-name-map_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'sample-name-map'",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/sample-name-map_tags"
                },
                {
                    "doc": "Output traversal statistics every time this many seconds elapse",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/seconds-between-progress-updates",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--seconds-between-progress-updates"
                    }
                },
                {
                    "doc": "Use the given sequence dictionary as the master/canonical sequence dictionary.  Must be a .dict file.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/sequence-dictionary",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--sequence-dictionary\", inputs['sequence-dictionary_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'sequence-dictionary'",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/sequence-dictionary_tags"
                },
                {
                    "doc": "display hidden arguments",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/showHidden",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--showHidden",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Undocumented option",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/TMP_DIR",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--TMP_DIR\", inputs['TMP_DIR_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                {
                                    "type": "array",
                                    "items": "string"
                                }
                            ]
                        }
                    ],
                    "doc": "A argument to set the tags of 'TMP_DIR'",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/TMP_DIR_tags"
                },
                {
                    "doc": "Whether to use the JdkDeflater (as opposed to IntelDeflater)",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/use-jdk-deflater",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--use-jdk-deflater",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Whether to use the JdkInflater (as opposed to IntelInflater)",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/use-jdk-inflater",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--use-jdk-inflater",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Boolean flag to enable checks on the sampleNameMap file. If true, tool checks whetherfeature readers are valid and shows a warning if sample names do not match with the headers. Defaults to false",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/validate-sample-name-map",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--validate-sample-name-map",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "GVCF files to be imported to GenomicsDB. Each file must containdata for only a single sample. Either this or sample-name-map must be specified.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/variant",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--variant\", inputs['variant_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                {
                                    "type": "array",
                                    "items": "string"
                                }
                            ]
                        }
                    ],
                    "doc": "A argument to set the tags of 'variant'",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/variant_tags"
                },
                {
                    "doc": "Control verbosity of logging.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/verbosity",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#GenomicsDBImport.cwl/GenomicsDBImport/verbosity/ERROR",
                                "#GenomicsDBImport.cwl/GenomicsDBImport/verbosity/WARNING",
                                "#GenomicsDBImport.cwl/GenomicsDBImport/verbosity/INFO",
                                "#GenomicsDBImport.cwl/GenomicsDBImport/verbosity/DEBUG"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--verbosity"
                    }
                },
                {
                    "doc": "display the version number for this tool",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/version",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--version",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/genomicsdb-workspace",
                    "doc": "Output folder corresponding to the input argument genomicsdb-workspace-path",
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs['genomicsdb-workspace-path'])"
                    }
                }
            ]
        },
        {
            "id": "#GenotypeGVCFs.cwl",
            "baseCommand": [
                "python3",
                "/gatk-local-io-wrapper.py",
                "[\"--variant\"]",
                "[]",
                "[\"-Xmx16000m\",\"-Xms16000m\"]",
                "GenotypeGVCFs"
            ],
            "class": "CommandLineTool",
            "doc": "Perform joint genotyping on one or more samples pre-called with HaplotypeCaller\n\n <p>\n This tool is designed to perform joint genotyping on a single input, which may contain one or many samples. In any\n case, the input samples must possess genotype likelihoods produced by HaplotypeCaller with `-ERC GVCF` or\n `-ERC BP_RESOLUTION`.\n\n\n <h3>Input</h3>\n <p>\n The GATK4 GenotypeGVCFs tool can take only one input track.  Options are 1) a single single-sample GVCF 2) a single\n multi-sample GVCF created by CombineGVCFs or 3) a GenomicsDB workspace created by GenomicsDBImport.\n A sample-level GVCF is produced by HaplotypeCaller with the `-ERC GVCF` setting.\n </p>\n\n <h3>Output</h3>\n <p>\n A final VCF in which all samples have been jointly genotyped.\n </p>\n\n <h3>Usage example</h3>\n\n <h4>Perform joint genotyping on a singular sample by providing a single-sample GVCF or on a cohort by providing a combined multi-sample GVCF</h4>\n <pre>\n gatk --java-options \"-Xmx4g\" GenotypeGVCFs \\\n   -R Homo_sapiens_assembly38.fasta \\\n   -V input.g.vcf.gz \\\n   -O output.vcf.gz\n </pre>\n\n <h4>Perform joint genotyping on GenomicsDB workspace created with GenomicsDBImport</h4>\n <pre>\n gatk --java-options \"-Xmx4g\" GenotypeGVCFs \\\n   -R Homo_sapiens_assembly38.fasta \\\n   -V gendb://my_database \\\n   -O output.vcf.gz\n </pre>\n\n <h3>Caveats</h3>\n <ul>\n   <li>Only GVCF files produced by HaplotypeCaller (or CombineGVCFs) can be used as input for this tool. Some other\n programs produce files that they call GVCFs but those lack some important information (accurate genotype likelihoods\n for every position) that GenotypeGVCFs requires for its operation.</li>\n   <li>Cannot take multiple GVCF files in one command.</li>\n </ul>\n\n <h3>Special note on ploidy</h3>\n <p>This tool is able to handle any ploidy (or mix of ploidies) intelligently; there is no need to specify ploidy\n for non-diploid organisms.</p>",
            "temporaryFailCodes": [
                3,
                250
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "/**\n * File of functions to be added to cwl files\n */\n\nfunction generateGATK4BooleanValue(){\n    /**\n     * Boolean types in GATK 4 are expressed on the command line as --<PREFIX> \"true\"/\"false\",\n     * so patch here\n     */\n    if(self === true || self === false){\n        return self.toString()\n    }\n\n    return self;\n}\n\nfunction addTagToArgument(tagObject, argument, prefix){\n    var allTags = Array.isArray(tagObject) ? tagObject.join(\",\") : tagObject;\n    return [prefix + \":\" + allTags, argument];\n}\n\nfunction applyTagsToArgument(prefix, tags){\n    /**\n     * Function to be used in the field valueFrom of File objects to add gatk tags.\n     */\n\n    if(!self){\n        return null;\n    }\n    else if(!tags){\n        return generateArrayCmd(prefix);\n    }\n    else{\n        if(Array.isArray(self)){\n            if(!Array.isArray(tags) || self.length !== tags.length){\n                throw new TypeError(\"Argument '\" + prefix + \"' tag field is invalid\");\n            }\n\n            var value = self.map(function(element, i) {\n                return addTagToArgument(tags[i], element);\n            }).reduce(function(a, b){return a.concat(b)})\n\n            return value;\n        }\n        else{\n            return addTagToArgument(tags, self);\n        }\n    }\n}\n\nfunction generateArrayCmd(prefix){\n    /**\n     * Function to be used in the field valueFrom of array objects, so that arrays are optional\n     * and prefixes are handled properly.\n     *\n     * The issue that this solves is documented here:\n     * https://www.biostars.org/p/258414/#260140\n     */\n    if(!self){\n        return null;\n    }\n\n    if(!Array.isArray(self)){\n        self = [self];\n    }\n\n    var output = [];\n    self.forEach(function(element) {\n        output.push(prefix);\n        output.push(element);\n    })\n\n    return output;\n}"
                    ]
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mercury/gatk-4.0.0.0-local-io-wrapper:v4"
                }
            ],
            "inputs": [
                {
                    "doc": "Reference sequence file",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/reference",
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--reference\", inputs['reference_tags']))"
                    },
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ]
                },
                {
                    "doc": "BAM/SAM/CRAM file containing reads",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/input",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--input\", inputs['input_tags']))"
                    },
                    "secondaryFiles": ".crai"
                },
                {
                    "doc": "Threshold number of ambiguous bases. If null, uses threshold fraction; otherwise, overrides threshold fraction.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/ambig-filter-bases",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--ambig-filter-bases"
                    }
                },
                {
                    "doc": "Threshold fraction of ambiguous bases",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/ambig-filter-frac",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--ambig-filter-frac"
                    }
                },
                {
                    "doc": "Maximum length of fragment (insert size)",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/max-fragment-length",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-fragment-length"
                    }
                },
                {
                    "doc": "Name of the library to keep",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/library",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--library\"))"
                    }
                },
                {
                    "doc": "Maximum mapping quality to keep (inclusive)",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/maximum-mapping-quality",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--maximum-mapping-quality"
                    }
                },
                {
                    "doc": "Minimum mapping quality to keep (inclusive)",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/minimum-mapping-quality",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--minimum-mapping-quality"
                    }
                },
                {
                    "doc": "Allow a read to be filtered out based on having only 1 soft-clipped block. By default, both ends must have a soft-clipped block, setting this flag requires only 1 soft-clipped block",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/dont-require-soft-clips-both-ends",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--dont-require-soft-clips-both-ends",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Minimum number of aligned bases",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/filter-too-short",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--filter-too-short"
                    }
                },
                {
                    "doc": "Platform attribute (PL) to match",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/platform-filter-name",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--platform-filter-name\"))"
                    }
                },
                {
                    "doc": "Platform unit (PU) to filter out",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/black-listed-lanes",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--black-listed-lanes\"))"
                    }
                },
                {
                    "doc": "The name of the read group to filter out",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/read-group-black-list",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--read-group-black-list\"))"
                    }
                },
                {
                    "doc": "The name of the read group to keep",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/keep-read-group",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--keep-read-group"
                    }
                },
                {
                    "doc": "Keep only reads with length at most equal to the specified value",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/max-read-length",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-read-length"
                    }
                },
                {
                    "doc": "Keep only reads with length at least equal to the specified value",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/min-read-length",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--min-read-length"
                    }
                },
                {
                    "doc": "Keep only reads with this read name",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/read-name",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--read-name"
                    }
                },
                {
                    "doc": "Keep only reads on the reverse strand",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/keep-reverse-strand-only",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--keep-reverse-strand-only",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "The name of the sample(s) to keep, filtering out all others",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/sample",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--sample\"))"
                    }
                },
                {
                    "doc": "If true, adds a PG tag to created SAM/BAM/CRAM files.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/add-output-sam-program-record",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--add-output-sam-program-record",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, adds a command line header line to created VCF files.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/add-output-vcf-command-line",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--add-output-vcf-command-line",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If provided, we will annotate records with the number of alternate alleles that were discovered (but not necessarily genotyped) at a given site",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/annotate-with-num-discovered-alleles",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--annotate-with-num-discovered-alleles",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "One or more specific annotations to add to variant calls",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/annotation",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--annotation\"))"
                    }
                },
                {
                    "doc": "One or more groups of annotations to apply to variant calls",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/annotation-group",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--annotation-group\"))"
                    }
                },
                {
                    "doc": "One or more specific annotations to exclude from variant calls",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/annotations-to-exclude",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--annotations-to-exclude\"))"
                    }
                },
                {
                    "doc": "read one or more arguments files and add them to the command line",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/arguments_file",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--arguments_file\", inputs['arguments_file_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                {
                                    "type": "array",
                                    "items": "string"
                                }
                            ]
                        }
                    ],
                    "doc": "A argument to set the tags of 'arguments_file'",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/arguments_file_tags"
                },
                {
                    "doc": "Size of the cloud-only prefetch buffer (in MB; 0 to disable). Defaults to cloudPrefetchBuffer if unset.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/cloud-index-prefetch-buffer",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--cloud-index-prefetch-buffer"
                    }
                },
                {
                    "doc": "Size of the cloud-only prefetch buffer (in MB; 0 to disable).",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/cloud-prefetch-buffer",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--cloud-prefetch-buffer"
                    }
                },
                {
                    "doc": "If true, create a BAM/CRAM index when writing a coordinate-sorted BAM/CRAM file.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/create-output-bam-index",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--create-output-bam-index",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, create a MD5 digest for any BAM/SAM/CRAM file created",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/create-output-bam-md5",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--create-output-bam-md5",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, create a VCF index when writing a coordinate-sorted VCF file.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/create-output-variant-index",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--create-output-variant-index",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, create a a MD5 digest any VCF file created.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/create-output-variant-md5",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--create-output-variant-md5",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "dbSNP file",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/dbsnp",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--dbsnp\", inputs['dbsnp_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'dbsnp'",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/dbsnp_tags"
                },
                {
                    "doc": "If true, don't cache bam indexes, this will reduce memory requirements but may harm performance if many intervals are specified.  Caching is automatically disabled if there are no intervals specified.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/disable-bam-index-caching",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--disable-bam-index-caching",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Read filters to be disabled before analysis",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/disable-read-filter",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--disable-read-filter\"))"
                    }
                },
                {
                    "doc": "If specified, do not check the sequence dictionaries from our inputs for compatibility. Use at your own risk!",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/disable-sequence-dictionary-validation",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--disable-sequence-dictionary-validation",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Disable all tool default read filters",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/disable-tool-default-read-filters",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--disable-tool-default-read-filters",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "One or more genomic intervals to exclude from processing",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/exclude-intervals",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--exclude-intervals\"))"
                    }
                },
                {
                    "doc": "A configuration file to use with the GATK.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/gatk-config-file",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--gatk-config-file\", inputs['gatk-config-file_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'gatk-config-file'",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/gatk-config-file_tags"
                },
                {
                    "doc": "If the GCS bucket channel errors out, how many times it will attempt to re-initiate the connection",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/gcs-max-retries",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--gcs-max-retries"
                    }
                },
                {
                    "doc": "Heterozygosity value used to compute prior likelihoods for any locus.  See the GATKDocs for full details on the meaning of this population genetics concept",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/heterozygosity",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--heterozygosity"
                    }
                },
                {
                    "doc": "Standard deviation of eterozygosity for SNP and indel calling.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/heterozygosity-stdev",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--heterozygosity-stdev"
                    }
                },
                {
                    "doc": "Heterozygosity for indel calling.  See the GATKDocs for heterozygosity for full details on the meaning of this population genetics concept",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/indel-heterozygosity",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--indel-heterozygosity"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                {
                                    "type": "array",
                                    "items": "string"
                                }
                            ]
                        }
                    ],
                    "doc": "A argument to set the tags of 'input'",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/input_tags"
                },
                {
                    "doc": "Input prior for calls",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/input-prior",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "double",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "double"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--input-prior\"))"
                    }
                },
                {
                    "doc": "Amount of padding (in bp) to add to each interval you are excluding.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/interval-exclusion-padding",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--interval-exclusion-padding"
                    }
                },
                {
                    "doc": "Interval merging rule for abutting intervals",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/interval-merging-rule",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#GenotypeGVCFs.cwl/GenotypeGVCFs/interval-merging-rule/ALL",
                                "#GenotypeGVCFs.cwl/GenotypeGVCFs/interval-merging-rule/OVERLAPPING_ONLY"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--interval-merging-rule"
                    }
                },
                {
                    "doc": "Amount of padding (in bp) to add to each interval you are including.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/interval-padding",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--interval-padding"
                    }
                },
                {
                    "doc": "Set merging approach to use for combining interval inputs",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/interval-set-rule",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#GenotypeGVCFs.cwl/GenotypeGVCFs/interval-set-rule/UNION",
                                "#GenotypeGVCFs.cwl/GenotypeGVCFs/interval-set-rule/INTERSECTION"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--interval-set-rule"
                    }
                },
                {
                    "doc": "One or more genomic intervals over which to operate",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/intervals",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "File",
                                "string"
                            ],
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "File",
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--intervals\", inputs['intervals_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                {
                                    "type": "array",
                                    "items": "string"
                                }
                            ]
                        }
                    ],
                    "doc": "A argument to set the tags of 'intervals'",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/intervals_tags"
                },
                {
                    "doc": "Lenient processing of VCF files",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/lenient",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--lenient",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Maximum number of alternate alleles to genotype",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/max-alternate-alleles",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-alternate-alleles"
                    }
                },
                {
                    "doc": "Maximum number of genotypes to consider at any site",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/max-genotype-count",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-genotype-count"
                    }
                },
                {
                    "doc": "Restrict variant output to sites that start within provided intervals",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/only-output-calls-starting-in-intervals",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--only-output-calls-starting-in-intervals",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "File to which variants should be written",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/output-filename",
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--output"
                    }
                },
                {
                    "doc": "Whether to suppress job-summary info on System.err.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/QUIET",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--QUIET",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Read filters to be applied before analysis",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/read-filter",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--read-filter\"))"
                    }
                },
                {
                    "doc": "Indices to use for the read inputs. If specified, an index must be provided for every read input and in the same order as the read inputs. If this argument is not specified, the path to the index for each input will be inferred automatically.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/read-index",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--read-index\"))"
                    }
                },
                {
                    "doc": "Validation stringency for all SAM/BAM/CRAM/SRA files read by this program.  The default stringency value SILENT can improve performance when processing a BAM file in which variable-length data (read, qualities, tags) do not otherwise need to be decoded.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/read-validation-stringency",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#GenotypeGVCFs.cwl/GenotypeGVCFs/read-validation-stringency/STRICT",
                                "#GenotypeGVCFs.cwl/GenotypeGVCFs/read-validation-stringency/LENIENT",
                                "#GenotypeGVCFs.cwl/GenotypeGVCFs/read-validation-stringency/SILENT"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--read-validation-stringency"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'reference'",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/reference_tags"
                },
                {
                    "doc": "Ploidy (number of chromosomes) per sample. For pooled data, set to (Number of samples in each pool * Sample Ploidy).",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/sample-ploidy",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--sample-ploidy"
                    }
                },
                {
                    "doc": "Output traversal statistics every time this many seconds elapse",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/seconds-between-progress-updates",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--seconds-between-progress-updates"
                    }
                },
                {
                    "doc": "Use the given sequence dictionary as the master/canonical sequence dictionary.  Must be a .dict file.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/sequence-dictionary",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--sequence-dictionary\", inputs['sequence-dictionary_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'sequence-dictionary'",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/sequence-dictionary_tags"
                },
                {
                    "doc": "display hidden arguments",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/showHidden",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--showHidden",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "The minimum phred-scaled confidence threshold at which variants should be called",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/standard-min-confidence-threshold-for-calling",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--standard-min-confidence-threshold-for-calling"
                    }
                },
                {
                    "doc": "Undocumented option",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/TMP_DIR",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--TMP_DIR\", inputs['TMP_DIR_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                {
                                    "type": "array",
                                    "items": "string"
                                }
                            ]
                        }
                    ],
                    "doc": "A argument to set the tags of 'TMP_DIR'",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/TMP_DIR_tags"
                },
                {
                    "doc": "Whether to use the JdkDeflater (as opposed to IntelDeflater)",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/use-jdk-deflater",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--use-jdk-deflater",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Whether to use the JdkInflater (as opposed to IntelInflater)",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/use-jdk-inflater",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--use-jdk-inflater",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If provided, we will use the new AF model instead of the so-called exact model",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/use-new-qual-calculator",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--use-new-qual-calculator",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "A VCF file containing variants",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/variant",
                    "type": [
                        "File",
                        "Directory"
                    ],
                    "inputBinding": {
                        "prefix": "--variant",
                        "valueFrom": "${if(self.class==\"File\"){return self.path;} else {return \"gendb://\"+self.path;}}"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'variant'",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/variant_tags"
                },
                {
                    "doc": "Control verbosity of logging.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/verbosity",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#GenotypeGVCFs.cwl/GenotypeGVCFs/verbosity/ERROR",
                                "#GenotypeGVCFs.cwl/GenotypeGVCFs/verbosity/WARNING",
                                "#GenotypeGVCFs.cwl/GenotypeGVCFs/verbosity/INFO",
                                "#GenotypeGVCFs.cwl/GenotypeGVCFs/verbosity/DEBUG"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--verbosity"
                    }
                },
                {
                    "doc": "display the version number for this tool",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/version",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--version",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/bam-index",
                    "doc": "index file generated if create-output-bam-index is true",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": [
                            "$(inputs['output-filename']).idx",
                            "$(inputs['output-filename']).tbi"
                        ]
                    }
                },
                {
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/bam-md5",
                    "doc": "md5 file generated if create-output-bam-md5 is true",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs['output-filename']).md5"
                    }
                },
                {
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/variant-index",
                    "doc": "index file generated if create-output-variant-index is true",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": [
                            "$(inputs['output-filename']).idx",
                            "$(inputs['output-filename']).tbi"
                        ]
                    }
                },
                {
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/variant-md5",
                    "doc": "md5 file generated if create-output-variant-md5 is true",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs['output-filename']).md5"
                    }
                },
                {
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/output",
                    "doc": "Output file corresponding to the input argument output-filename",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs['output-filename'])"
                    }
                }
            ]
        },
        {
            "class": "Workflow",
            "hints": [
                {
                    "ramMin": 4000,
                    "coresMin": 1,
                    "tmpdirMin": 1000,
                    "class": "ResourceRequirement"
                },
                {
                    "outputTTL": 2592000,
                    "class": "http://arvados.org/cwl#IntermediateOutput"
                },
                {
                    "keep_cache": 1024,
                    "outputDirType": "keep_output_dir",
                    "class": "http://arvados.org/cwl#RuntimeConstraints"
                },
                {
                    "loadListing": "no_listing",
                    "class": "http://commonwl.org/cwltool#LoadListingRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#main/interval"
                },
                {
                    "type": "File",
                    "id": "#main/reference"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/variants"
                }
            ],
            "steps": [
                {
                    "id": "#main/genomics_db_import_gvcfs",
                    "run": "#GenomicsDBImport.cwl",
                    "hints": [
                        {
                            "coresMin": 6,
                            "ramMin": 18000,
                            "tmpdirMin": 1000,
                            "class": "ResourceRequirement"
                        },
                        {
                            "keep_cache": 1280,
                            "class": "http://arvados.org/cwl#RuntimeConstraints"
                        }
                    ],
                    "in": [
                        {
                            "default": 50,
                            "id": "#main/genomics_db_import_gvcfs/batch-size"
                        },
                        {
                            "default": "genomicsdb",
                            "id": "#main/genomics_db_import_gvcfs/genomicsdb-workspace-path"
                        },
                        {
                            "default": 500,
                            "id": "#main/genomics_db_import_gvcfs/interval-padding"
                        },
                        {
                            "source": "#main/interval",
                            "id": "#main/genomics_db_import_gvcfs/intervals"
                        },
                        {
                            "default": 5,
                            "id": "#main/genomics_db_import_gvcfs/reader-threads"
                        },
                        {
                            "source": "#main/variants",
                            "id": "#main/genomics_db_import_gvcfs/variant"
                        }
                    ],
                    "out": [
                        "#main/genomics_db_import_gvcfs/genomicsdb-workspace"
                    ]
                },
                {
                    "id": "#main/genotype_gvcfs",
                    "run": "#GenotypeGVCFs.cwl",
                    "hints": [
                        {
                            "ramMin": 20000,
                            "coresMin": 1,
                            "tmpdirMin": 1000,
                            "class": "ResourceRequirement"
                        }
                    ],
                    "in": [
                        {
                            "default": true,
                            "id": "#main/genotype_gvcfs/create-output-variant-index"
                        },
                        {
                            "source": "#main/interval",
                            "id": "#main/genotype_gvcfs/intervals"
                        },
                        {
                            "default": true,
                            "id": "#main/genotype_gvcfs/only-output-calls-starting-in-intervals"
                        },
                        {
                            "valueFrom": "output.g.vcf.gz",
                            "id": "#main/genotype_gvcfs/output-filename"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/genotype_gvcfs/reference"
                        },
                        {
                            "default": true,
                            "id": "#main/genotype_gvcfs/use-new-qual-calculator"
                        },
                        {
                            "source": "#main/genomics_db_import_gvcfs/genomicsdb-workspace",
                            "id": "#main/genotype_gvcfs/variant"
                        }
                    ],
                    "out": [
                        "#main/genotype_gvcfs/output",
                        "#main/genotype_gvcfs/variant-index"
                    ]
                },
                {
                    "id": "#main/multisample_gvcf_output_with_index",
                    "in": [
                        {
                            "source": "#main/genotype_gvcfs/output",
                            "id": "#main/multisample_gvcf_output_with_index/main_file"
                        },
                        {
                            "source": "#main/genotype_gvcfs/variant-index",
                            "id": "#main/multisample_gvcf_output_with_index/secondary_files"
                        }
                    ],
                    "out": [
                        "#main/multisample_gvcf_output_with_index/file_with_secondary_files"
                    ],
                    "run": "#combine_files.cwl"
                }
            ],
            "outputs": [
                {
                    "id": "#main/multisample-gvcf-output",
                    "type": "File",
                    "outputSource": "#main/multisample_gvcf_output_with_index/file_with_secondary_files"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0",
    "$namespaces": {
        "arv": "http://arvados.org/cwl#",
        "cwltool": "http://commonwl.org/cwltool#"
    }
}
